@@ -2,7 +2,7 @@
 #
 # Prepare the stage...
 #
-# $Id: moses-install.pl,v 1.7 2009/04/08 22:42:51 kawas Exp $
+# $Id: install.pl,v 1.7 2006/11/11 23:04:34 senger Exp $
 # Contact: Martin Senger <martin.senger@gmail.com>
 # -----------------------------------------------------------
 
@@ -24,7 +24,6 @@ Usage: [-F]
        services.log
        parser.log
        MobyServer.cgi
-       AsyncMobyServer.cgi
     The existing files are not overwritten - unless an option -F
     has been used.
 
@@ -64,19 +63,10 @@ END_OF_USAGE
 			  IO::Scalar
 			  Unicode::String
 			  ) ) {
-		check_module ($module);
+	check_module ($module);
     }
-    # check for async libraries if user wants to ....
-    print STDOUT "Shall we check for the moby-async libraries\n\t(do this only if you plan on creating soap based\n\t async moby services)? y/n [n]";
-    my $tmp = <STDIN>;
-    $tmp =~ s/\s//g; 
-    if ($tmp =~ /y/i) {
-    	check_module('MOBY::Client::Central');
-		check_module('WSRF::Lite'); 
-    }
-
     if (MSWIN) {
-		check_module ('Term::ReadLine');
+	check_module ('Term::ReadLine');
 	{
 	    local $^W = 0;
 	    $SimplePrompt::Terminal = Term::ReadLine->new ('Installation');
@@ -134,7 +124,7 @@ sub prompt_for_registry {
     my @regs = MOSES::MOBY::Cache::Registries->list;
     my $registry = pprompt ("What registry to use? [default] ",
 			   -m => [@regs]);
-    return $registry ||= 'default';
+    $registry ||= 'default';
 }
 
 # create a file from a template
@@ -190,18 +180,6 @@ eval {
 };
 say $@ ? $@ : "Created install directory '$pmoses_home'.";
 
-# create install directory if necessary
-eval {
-	my ($v, $d, $f) = File::Spec->splitpath( $pmoses_home . "/cgi" );
-	my $dir = File::Spec->catdir($v);
-	foreach my $part ( File::Spec->splitdir( ($d.$f ) ) ) {
-	   	$dir = File::Spec->catdir($dir, $part);
-   		next if -d $dir or -e $dir;
-	    mkdir( $dir ) || die("Error creating installation directory directory '".$dir."':\n$!");
-	}
-};
-say $@ ? $@ : "Created install directory '$pmoses_home/cgi'.";
-
 # create install directory if necessary
 eval {
 	my ($v, $d, $f) = File::Spec->splitpath( $samples_home );
@@ -251,8 +229,6 @@ my $services_dir = $MOBYCFG::GENERATORS_IMPL_OUTDIR ||
     "$pmoses_home/services";
 my $services_table = $MOBYCFG::GENERATORS_IMPL_SERVICES_TABLE ||
     'SERVICES_TABLE';
-my $async_services_table = $MOBYCFG::GENERATORS_IMPL_SERVICES_TABLE ||
-    'ASYNC_SERVICES_TABLE';
 
 my $cgibin_file = "$pmoses_home/MobyServer.cgi";
 if (-e $cgibin_file and ! $opt_F) {
@@ -271,25 +247,6 @@ if (-e $cgibin_file and ! $opt_F) {
     chmod 0755, $cgibin_file;   # everybody can execute
 }
 
-# AsyncMobyServer.cgi file
-
-my $async_cgibin_file = "$pmoses_home/AsyncMobyServer.cgi";
-if (-e $async_cgibin_file and ! $opt_F) {
-    say "\nWeb Server file '$async_cgibin_file' exists.";
-    say "It will not be overwritten unless you start 'install.pl -F'.\n";
-} else {
-    file_from_template
-	($async_cgibin_file,
-	 File::ShareDir::dist_file('MOSES-MOBY','AsyncMobyServer.cgi.template'),
-	 'Web Server file',
-	 { '@PMOSES_HOME@'    => $pmoses_home,
-	   '@GENERATED_DIR@'  => $generated_dir,
-	   '@SERVICES_DIR@'   => $services_dir,
-	   '@ASYNC_SERVICE_TABLE@' => $async_services_table,
-       } );
-    chmod 0755, $async_cgibin_file;   # everybody can execute
-}
-
 # directory for local cache
 my $cachedir = $MOBYCFG::CACHEDIR ||
     prompt_for_directory ( 'Directory for local cache',
@@ -308,7 +265,10 @@ if ('y' eq pprompt ('Should I try to fill or update the local cache [y]? ', -ynd
 		say 'Using registry: ' . $registry;
 		say "(at $endpoint)\n";
 	
-		my $cache = MOSES::MOBY::Cache::Central->new (cachedir => $cachedir, registry=>$registry);
+		my $cache = MOSES::MOBY::Cache::Central->new (cachedir => $cachedir);
+		$cache->_namespace($uri);
+		$cache->_endpoint($endpoint);
+		
 		say "Getting the BioMOBY datatypes ...\n";
 		eval {
 			$cache->update_datatype_cache();
@@ -342,15 +302,13 @@ if (-e $config_file and ! $opt_F) {
 	($config_file,
 	 File::ShareDir::dist_file('MOSES-MOBY','moby-services.cfg.template'),
 	 'Configuration file',
-	 { '@CACHE_DIR@'        		=> $cachedir,
-	   '@REGISTRY@'         		=> $registry,
-	   '@GENERATED_DIR@'    		=> $generated_dir,
-	   '@SERVICES_DIR@'     		=> $services_dir,
-	   '@SERVICES_TABLE@'   		=> $services_table,
-	   '@ASYNC_SERVICES_TABLE@'   	=> $async_services_table,
-	   '@LOG4PERL_FILE@'    		=> $log4perl_file,
-	   '@LOGFILE@'          		=> $log_file1,
-	   '@USER_REGISTRIES_FILE_DIR@'	=> $pmoses_home,
+	 { '@CACHE_DIR@'        => $cachedir,
+	   '@REGISTRY@'         => $registry,
+	   '@GENERATED_DIR@'    => $generated_dir,
+	   '@SERVICES_DIR@'     => $services_dir,
+	   '@SERVICES_TABLE@'   => $services_table,
+	   '@LOG4PERL_FILE@'    => $log4perl_file,
+	   '@LOGFILE@'          => $log_file1,
 	   '@MABUHAY_RESOURCE@' =>
 	       "$samples_home/mabuhay.file",
 	   } );
@@ -369,21 +327,6 @@ file_from_template
 	 {} );
 }
 
-# install the user_registries file 
-my $registries_file =  "$MOBYCFG::USER_REGISTRIES_USER_REGISTRIES_DIR/$MOBYCFG::USER_REGISTRIES_USER_REGISTRIES_FILENAME" 
-	if $MOBYCFG::USER_REGISTRIES_USER_REGISTRIES_DIR and $MOBYCFG::USER_REGISTRIES_USER_REGISTRIES_FILENAME;
-$registries_file = File::Spec->catfile("$pmoses_home","USER_REGISTRIES") if not $registries_file or $registries_file eq "";
-if (-e $registries_file and ! $opt_F) {
-    say "User Registrie file $registries_file exists.";
-    say "It will be used and not overwritten unless you start 'install.pl -F'.\n";
-} else {
-file_from_template
-	($registries_file,
-	 File::ShareDir::dist_file('MOSES-MOBY', "USER_REGISTRIES"),
-	 'User Registries File',
-	 {} );
-}
-
 say 'Done.';
 
 package SimplePrompt;
