@@ -4,7 +4,7 @@
 #         Martin Senger <martin.senger@gmail.com>
 # For copyright and disclaimer see below.
 #
-# $Id: Central.pm,v 1.9 2009/10/09 17:29:28 kawas Exp $
+# $Id: Central.pm,v 1.5 2007/07/31 17:51:42 kawas Exp $
 #-----------------------------------------------------------------
 
 package MOSES::MOBY::Cache::Central;
@@ -21,7 +21,7 @@ use SOAP::Lite;
 use XML::LibXML;
 use File::Spec;
 use strict;
-use vars qw ($DEFAULT_REGISTRY_URL $VERSION);
+use vars qw ($DEFAULT_REGISTRY_URL);
 
 # names of cache directories/files
 use constant LIST_FILE          => '__L__I__S__T__';
@@ -30,15 +30,10 @@ use constant SERVICES_CACHE     => 'services';
 use constant NAMESPACES_CACHE   => 'namespaces';
 use constant SERVICETYPES_CACHE => 'serviceTypes';
 
-# the version of this file:
-$VERSION = sprintf "%d.%02d", q$Revision: 1.9 $ =~ /: (\d+)\.(\d+)/;
-
 =head1 NAME
 
 MOSES::MOBY::Cache::Central - access to locally cached Moby entities
 
-=cut
-
 =head1 SYNOPSIS
 
  use MOSES::MOBY::Cache::Central;
@@ -117,7 +112,7 @@ Details are in L<MOSES::MOBY::Base>. Here just a list of them:
 =item B<cachedir>
 
 A mandatory parameter containing a name of a local directory where is
-a Moby cache. The Moby cache directory can contain more caches (from
+a Moby cache. The Moby cache directory can contain mor caches (from
 more Moby registries). The location points to the top-level directory
 name. For example, if we have the following directory structure
 (containing caches from four different Moby registries):
@@ -146,11 +141,6 @@ synonyms in L<MOSES::MOBY::Cache::Registries>.
 For a default registry, use string 'default' (but there is no need to
 do so: default is default by default).
 
-=item B<registries>
-
-An object of type MOSES::MOBY::Cache::Registries that you can manipulate to add 
-more registries. See more about this object in L<MOSES::MOBY::Cache::Registries>.
-
 =back
 
 =cut
@@ -159,9 +149,9 @@ more registries. See more about this object in L<MOSES::MOBY::Cache::Registries>
     my %_allowed =
 	(
 	 cachedir  => undef,
-	 registries=> new MOSES::MOBY::Cache::Registries,
 	 registry  => { type => MOSES::MOBY::Base->STRING,
 			post => \&_check_registry },
+
 	 # undocumented, for internal use only (so far)
 	 datatypes => {type => 'MOSES::MOBY::Def::DataType', is_array => 1},
 #	 services  => {type => 'MOSES::MOBY::Def::Service',  is_array => 1},
@@ -184,7 +174,6 @@ sub _check_registry {
     $self->{registry} = $self->{registry} || $MOBYCFG::REGISTRY || 'default';
 }
 
-
 #-----------------------------------------------------------------
 
 =head1 SUBROUTINES
@@ -200,9 +189,9 @@ sub _endpoint {
     my ($self, $registry) = @_;
     $registry ||= $self->registry;
     return $registry if $registry =~ m"^http://";
-    my $reg = $self->registries->get ($registry);
+    my $reg = MOSES::MOBY::Cache::Registries->get ($registry);
     return $reg->{endpoint} if $reg;
-    return $self->registries->get ('default')->{endpoint};
+    return MOSES::MOBY::Cache::Registries->get ('default')->{endpoint};
 }
 
 #-----------------------------------------------------------------
@@ -213,10 +202,10 @@ sub _endpoint {
 sub _namespace {
     my ($self, $registry) = @_;
     $registry ||= $self->registry;
-    return "http://localhost/MOBY/Central" if $registry =~ m"^http://";
-    my $reg = $self->registries->get ($registry);
+    return $registry if $registry =~ m"^http://";
+    my $reg = MOSES::MOBY::Cache::Registries->get ($registry);
     return $reg->{namespace} if $reg;
-    return $self->registries->get ('default')->{namespace};
+    return MOSES::MOBY::Cache::Registries->get ('default')->{namespace};
 }
 
 
@@ -228,7 +217,6 @@ sub init {
     $self->SUPER::init();
     $self->registry ($MOBYCFG::REGISTRY || 'default');
     $self->cachedir ($MOBYCFG::CACHEDIR);
-	$self->registries( new MOSES::MOBY::Cache::Registries);
     $self->datatypes ([]);
 #    $self->services ([]);
 }
@@ -318,7 +306,7 @@ sub create_datatype_cache {
 				sub {
 					my $soap = shift;
 					my $res  = shift;
-					$self->throw ("There was a problem calling the registry: " . $self->_endpoint . "\@ " . $self->_namespace . ".\n" . $res);	
+					$self->throw ("There was a problem calling the registry: " . $self->_endpoint . "\@ " . $self->_namespace . ".\n" + $res);	
 				}
 			  );
 
@@ -422,7 +410,7 @@ sub update_datatype_cache {
 				sub {
 					my $soap = shift;
 					my $res  = shift;
-					$self->throw ("There was a problem calling the registry: " . $self->_endpoint . "\@ " . $self->_namespace . ".\n" . $res);	
+					$self->throw ("There was a problem calling the registry: " . $self->_endpoint . "\@ " . $self->_namespace . ".\n" + $res);	
 				}
 			  );
 
@@ -503,7 +491,7 @@ sub create_service_cache {
 				sub {
 					my $soap = shift;
 					my $res  = shift;
-					$self->throw ("There was a problem calling the registry: " . $self->_endpoint . "\@ " . $self->_namespace . ".\n" . $res);	
+					$self->throw ("There was a problem calling the registry: " . $self->_endpoint . "\@ " . $self->_namespace . ".\n" + $res);	
 				}
 			  );
 
@@ -606,7 +594,7 @@ sub update_service_cache {
 				sub {
 					my $soap = shift;
 					my $res  = shift;
-					$self->throw ("There was a problem calling the registry: " . $self->_endpoint . "\@ " . $self->_namespace . ".\n" . $res);	
+					$self->throw ("There was a problem calling the registry: " . $self->_endpoint . "\@ " . $self->_namespace . ".\n" + $res);	
 				}
 			  );
 
@@ -708,13 +696,13 @@ sub _createDataTypeFromXML {
     while ( $count > 0 ) {
 	my $node         = $nodes->get_node( $count-- );
 	my $relationship = $node->getAttribute('relationshipType');
-	if ( $relationship =~ /^.*isa$/i ) {
+	if ( $relationship =~ /.*:isa$/ ) {
 	    my $parent = $node->getChildrenByTagName('objectType');
 	    my $isa    = $parent->get_node(1)->textContent
 		if ( $parent and $parent->get_node(1) and $parent->get_node(1) );
 	    $datatype->parent($isa);
 	}
-	elsif ( $relationship =~ /^.*hasa$/i ) {
+	elsif ( $relationship =~ /.*:hasa$/ ) {
 	    my $pNode = $node->getChildrenByTagName('objectType');
 	    for ( my $i = 1 ; $i <= $pNode->size() ; $i++ ) {
 		my $article = $pNode->get_node($i)->getAttribute('articleName')
@@ -735,7 +723,7 @@ sub _createDataTypeFromXML {
 		     );
 	    }
 	}
-	elsif ( $relationship =~ /^.*has$/i ) {
+	elsif ( $relationship =~ /.*:has$/ ) {
 	    my $pNode = $node->getChildrenByTagName('objectType');
 	    for ( my $i = 1 ; $i <= $pNode->size() ; $i++ ) {
 		my $article = $pNode->get_node($i)->getAttribute('articleName')
@@ -991,7 +979,7 @@ sub _createServiceFromXML {
     $service->lsid($service_node->getAttribute('lsid') || '');
     $service->type($service_node->getChildrenByTagName('serviceType')->get_node(1)->textContent) if $service_node->getChildrenByTagName('serviceType')->size() > 0;
     $service->authoritative($service_node->getChildrenByTagName('authoritative')->get_node(1)->textContent) if $service_node->getChildrenByTagName('authoritative')->size() > 0;
-    $service->category($service_node->getChildrenByTagName('Category')->get_node(1)->textContent) if $service_node->getChildrenByTagName('Category')->size() > 0;
+    $service->category($service_node->getChildrenByTagName('category')->get_node(1)->textContent) if $service_node->getChildrenByTagName('category')->size() > 0;
     $service->description($service_node->getChildrenByTagName('Description')->get_node(1)->textContent) if $service_node->getChildrenByTagName('Description')->size() > 0;
     $service->email($service_node->getChildrenByTagName('contactEmail')->get_node(1)->textContent) if $service_node->getChildrenByTagName('contactEmail')->size() > 0;
     $service->signatureURL($service_node->getChildrenByTagName('signatureURL')->get_node(1)->textContent) if $service_node->getChildrenByTagName('signatureURL')->size() > 0;
@@ -1218,7 +1206,7 @@ sub cache_exists {
 
 
 #-----------------------------------------------------------------
-# create_cache_dirs
+# cache_exists
 #-----------------------------------------------------------------
 
 =head2 create_cache_dirs
@@ -1250,5 +1238,6 @@ sub create_cache_dirs {
     }
 }
 
+
 1;
 __END__
