@@ -4,7 +4,7 @@
 #         Martin Senger <martin.senger@gmail.com>
 # For copyright and disclaimer see below.
 #
-# $Id: Object.pm,v 1.5 2010/12/08 16:14:13 kawas Exp $
+# $Id: Object.pm,v 1.1 2006/10/13 21:51:16 senger Exp $
 #-----------------------------------------------------------------
 
 package MOSES::MOBY::Data::Object;
@@ -12,10 +12,6 @@ use base ("MOSES::MOBY::Base");
 use MOSES::MOBY::Tags;
 use strict;
 
-# add versioning to this module
-use vars qw /$VERSION/;
-$VERSION = sprintf "%d.%02d", q$Revision: 1.5 $ =~ /: (\d+)\.(\d+)/;
-
 #-----------------------------------------------------------------
 # load all modules needed for my attributes
 #-----------------------------------------------------------------
@@ -239,7 +235,7 @@ sub _add_XML_element {
 	 provision => 1,
 	 );
     if ($name eq 'value' and $self->primitive) {
-	if (defined $value) {
+	if ($value) {
 	    if ($self->{cdata}) {  # don't use: $self->cdata because not everybody has it
 		$root->appendChild (XML::LibXML::CDATASection->new ($self->_express_value ($value)));
 	    } else {
