@@ -4,17 +4,13 @@
 #         Edward Kawas <edward.kawas@gmail.com>
 # For copyright and disclaimer see below.
 #
-# $Id: Utils.pm,v 1.7 2009/10/13 16:46:21 kawas Exp $
+# $Id: Utils.pm,v 1.1 2006/10/13 21:51:16 senger Exp $
 #-----------------------------------------------------------------
 
 package MOSES::MOBY::Generators::Utils;
 use File::Spec;
 use strict;
 
-# add versioning to this module
-use vars qw /$VERSION/;
-$VERSION = sprintf "%d.%02d", q$Revision: 1.7 $ =~ /: (\d+)\.(\d+)/;
-
 =head1 NAME
 
 MOSES::MOBY::Utils - what does not fit elsewhere
@@ -24,7 +20,7 @@ MOSES::MOBY::Utils - what does not fit elsewhere
  # find a file located somewhere in @INC
  use MOSES::MOBY::Generators::Utils;
  my $file = MOSES::MOBY::Generators::Utils->find_file ('resource.file');
-
+ 
 =head1 DESCRIPTION
 
 General purpose utilities.
@@ -36,6 +32,12 @@ General purpose utilities.
 
 =head1 SUBROUTINES
 
+=cut
+
+#-----------------------------------------------------------------
+# find_file
+#-----------------------------------------------------------------
+
 =head2 find_file
 
 Try to locate a file whose name is created from the C<$default_start>
@@ -49,34 +51,18 @@ There are two or more arguments: C<$default_start> and C<@names>.
 
 =cut
 
-my %full_path_of = ();
-
-#-----------------------------------------------------------------
-# find_file
-#-----------------------------------------------------------------
 sub find_file {
     my ($self, $default_start, @names) = @_;
     my $fixed_part = File::Spec->catfile (@names);
-    return $full_path_of{ $fixed_part } if exists $full_path_of{ $fixed_part };
-
     my $result = File::Spec->catfile ($default_start, $fixed_part);
-    if (-e $result) {
-        $full_path_of{ $fixed_part } = $result;
-        return $result;
-    }
+    return $result if -e $result;
 
     foreach my $idx (0 .. $#INC) {
-        $result = File::Spec->catfile ($INC[$idx], $fixed_part);
-        if (-e $result) {
-            $full_path_of{ $fixed_part } = $result;
-            return $result;
-        }
+	$result = File::Spec->catfile ($INC[$idx], $fixed_part);
+	return $result if -e $result;
     }
-    $result = File::Spec->catfile ($default_start, $fixed_part);
-    $full_path_of{ $fixed_part } = $result;
-    return $result;
+    return File::Spec->catfile ($default_start, $fixed_part);
 }
 
 1;
-
 __END__
